% DRAWS_MAX.M takes draws from a Normal-Wishart posterior, recalculates the impulse responses
% and collects them in order to produce confidence bands for impulse responses and
% variance decompositions.
% The formulas for the Normal-Wishart density are taken from Uhlig, 1994,
% "What Macroeconomists Should Know About Unit Roots: A Bayesian Perspective,"
% Econometric Theory 10, 645-671, appendix.
% Additionally, programs are needed to draw from a Wishart distribution.

% DRAWS_DW is taylor-made to work with DO_BENCHMARK in crunch_dw.m.

clear;
tic

MONTE_DRAWS =  100;

TAKE_POST_DRAWS = 1;
DRAWS_HORIZON = 120;
DRAWS_HOW_FAR = 120;
TMP = 0;
NVAR_MAX = 6;  % The max. number of variables, for which impulse responses can be stored.
               % If this number should be increased, also change the following couple of lines:
% To store impulse responses etc..:  I assume a maximum of NVAR_MAX variables so far.

ir1 = [];
ir2 = [];
ir3 = [];
ir4 = [];
ir5 = [];
ir6 = [];

fv1 = [];
fv2 = [];
fv3 = [];
fv4 = [];
fv5 = [];
fv6 = [];

mon_agg_draws = [];

sernew1 = [];
sernew2 = [];
sernew3 = [];
sernew4 = [];
sernew5 = [];
sernew6 = [];

tot_draws = 0;
tot_prev  = 0;
suc_draws = 0;


if TMP,
   disp('I hope you are on Peters SPARC20!');
else
   disp('I hope I can save into your current directory');
end;

data;
var;
DRAWS_HOW_FAR = min(DRAWS_HOW_FAR,DRAWS_HORIZON);
HORIZON = DRAWS_HORIZON; 
HOW_FAR = DRAWS_HOW_FAR;


% First: do the OLSE:
olse;

% Next: do the Bayesian paramaters:
bayes;

time_per_draw = toc;
for draw = 1 : MONTE_DRAWS,
   tot_prev = tot_draws;
   if TAKE_POST_DRAWS,
      % draw hh
      hh = drawwish(nu_t,S_t);
      sig = inv(hh);
      % draw bb
      bb = B_t + Ntinv_low * randn(LEADTRENDS + nvar*nlags,nvar) * chol(sig);
   else
      sig = sig_olse;
      bb = b_olse;
   end;
   crunch_dw;
   suc_draws = suc_draws + (tot_draws > tot_prev);
     % counts for how many "draw", the tot_draws number was
     % actually increased.
   tm = toc;
   disp(sprintf('DRAWS.M: draw # %5.0f out of %5.0f, tot_draws = %6.0f. Time:%10.2f',draw,MONTE_DRAWS,tot_draws,tm));
end;
time_per_draw = (toc - time_per_draw)/MONTE_DRAWS;

if TMP,
   save /tmp/uhlig/monte
else
   save monte
end;
time_total = toc;
disp(sprintf('Time per draw: %10.3f',time_per_draw));
disp(sprintf('Time total: %10.3f',time_total));



   

   
   



