% MONINDIC.M constructs a monetary indicator, given an impulse vector aa.

DO_GRAPHS = 0;
DO_EPS = 1;
ESTIM_PHI = 1; % = 1, if you want to estimate PHI
PHI = 0; % 0.95; % 1; % in case PHI is not estimated


sig_tilde = sig - aa * aa'; % should be singular, but we play it safe:
% find the eigenvector to the smallest eigenvalue
% which should also be a vector of the unique
% one-dim. nullspace of sig_tilde. 
[v,d]=eig(sig_tilde);
[ds,di]=sort(abs(diag(d))); % Sorts ascendingly.  d(di(1)) is smallest eigenvalue.
v0 = v(:,di(1));
v0 = v0/(v0'*aa);           % Rescale so that v0'*aa = 1.
% Now, u1 = epsilon*v0, where epsilon is the one-step
% ahead pred. error is the mon. policy stance, read
% as a row vector.
epsln = yy - xx*bb;
mon_ind = epsln*v0;

piece = nlags+1:max(size(time));
if ESTIM_PHI,
   xxx = [ 0*mon_ind + 1, series(piece,6), series(piece-1,6) ];
   coefs = (xxx'*xxx) \ (xxx'*mon_ind);
   PHI = - coefs(3)/coefs(2);
end;
mon_agg = mon_ind;
if abs(PHI) <= 1, % forward dynamics is stable
   for j = 2 : max(size(mon_ind)),
      mon_agg(j) = PHI*mon_agg(j-1)+mon_ind(j);
   end;
else % backward dynamics is stable
   for j = max(size(mon_ind)) - 1 : 1,
      mon_agg(j) = (1/PHI)*mon_agg(j+1)+mon_ind(j);
   end;
end;  

if DO_GRAPHS,
   plot(time(piece),mon_ind,time(piece),0*mon_ind);
   title('An indicator of monetary policy surprises');
   ylabel('Degree of tightness');
   xlabel('Date');
   pause;
   
   plot(time(piece),cumsum(mon_ind),time(piece),0*mon_ind);
   title('An indicator of monetary policy (random walk)');
   ylabel('Degree of tightness');
   xlabel('Date');
   pause;
   
   
   plot(time(piece),mon_agg,time(piece),0*mon_ind);
   title(sprintf('An indicator of monetary policy (phi=%5.3f)',PHI));
   ylabel('Degree of tightness');
   xlabel('Date');
   pause;
   
   plot(time(piece),mon_agg,...
      time,series(:,6)*scale_old(6),'-.',time,series(:,6)*0);
   title(sprintf('An indicator of monetary policy (phi=%5.2f) vs FFR',PHI));
   ylabel('Degree of tightness, FFR');
   text(time(nlags+1+70),mon_agg(70),'Indicator');
   text(time(100),series(100,6)*scale_old(6),'Fed.Funds Rate');
   xlabel('Date');
   if DO_EPS,
      print -deps monindic.eps
   end;
   pause;
   
end;






