% MONINDIC_PLOT.M plots the monetary policy indicator  
DO_PLOTS = 1;
DO_EPSFILES = 1;
DO_2STDDEV = 0; % = 1: two standard dev. error bands, = 0: one standard dev. error bands
DO_SUBTRACT_AVERAGE = 1;
DO_ONLY_MEDIAN = 0;
% the following choices only make sense, if 
% DO_ESTIM = 0, PHI = 0 in monindic.m, i.e.
% if the raw v(a) have been stored.
% Otherwise, set both DO_CUMSUMDRAWS = 0 and DO_CUMSUMQUANT = 0 and DO_MA = 0
DO_CUMSUMDRAWS = 0; % = 1: calculates some average draw by draw
DO_CUMSUMQUANT = 0; % = 1: calculates some average of the draw quantiles
DO_MA = 0; % = 1: MA-average. = 0: AR-average
PLOT_PHI = 1; % if AR-average: the AR(1) coefficient
N_MA_AV = 12; % if MA-average: the number of periods to be averaged

FONT_SIZE = 16; % FontSize

CHOICE = 'n'; % 'z';

if DO_2STDDEV, % converting two standard dev. into quantiles, using normal distrib:
   uq = 0.9772;
   lq = 0.0228;
else
   uq = 0.8413;
   lq = 0.1587;
end;

global ir LEADTRENDS aa nlags nvar varvec bb scale_fct
global eigsqrt eigvec vv ir aa nvar sphere
global HOW_FAR WEIGHTS SIDE SCALE ALPHSUM

if CHOICE == '0',
   load montchol
   DO_COUNTER = 0;
elseif CHOICE == 'a', 
   load monte_a
   DO_COUNTER = 0;
elseif CHOICE == 'b', 
   load monte_b
   DO_COUNTER = 0;
elseif CHOICE == '2',
   load monte_b2
   DO_COUNTER = 1;
elseif CHOICE == 'c', 
   load monte_c
   DO_COUNTER = 0;
elseif CHOICE == 'n',
else
   load monte
   DO_COUNTER = 1;
end;




if DO_PLOTS,
   if DO_MA,
      piece = nlags+1+N_MA_AV:max(size(time));
   else
      piece = nlags+1:max(size(time));
   end;
   ti = time(piece);
   m_raw = mon_agg_draws;
   if DO_SUBTRACT_AVERAGE,
      sz = size(m_raw);
      m_raw = m_raw - ones(sz(1),1)*mean(m_raw);
   end;
   if DO_CUMSUMDRAWS,
      if DO_MA,
         m_ma = 0 * m_raw(1:max(size(ti)),:);
         for j = 1 : max(size(ti)),
            for l = 1 : N_MA_AV,
               m_ma(j,:) = m_ma(j,:) + m_raw(j+N_MA_AV-l,:);
            end;
         end;
         m_raw = m_ma;
      else
         for j = 2 : max(size(ti)),
            m_raw(j,:) = PLOT_PHI*m_raw(j-1,:) + m_raw(j,:);
         end;
      end;
   end;
   
   m_sort = sort(m_raw');
   m_sort = m_sort';
   number_of_draws = size(m_sort);
   number_of_draws = number_of_draws(2);
   m_mid  = interp1(1:number_of_draws,m_sort',.5*(number_of_draws-1)+1);
   m_up   = interp1(1:number_of_draws,m_sort',uq*(number_of_draws-1)+1);
   m_down = interp1(1:number_of_draws,m_sort',lq*(number_of_draws-1)+1);
   if DO_CUMSUMQUANT,
      if DO_MA,
         m_ma = 0 * m_raw(1:max(size(ti)),1:3);
         m_col = [ m_down',m_mid',m_up'];
         for j = 1 : max(size(ti)),
            for l = 1 : N_MA_AV,
               m_ma(j,:) = m_ma(j,:) + m_col(j+N_MA_AV-l,:);
            end;
         end;
         m_down = m_ma(:,1);m_down=m_down';
         m_mid  = m_ma(:,2);m_mid=m_mid';
         m_up   = m_ma(:,3);m_up=m_up';
      else
         for j = 2 : max(size(m_mid)),
            m_mid(j) = PLOT_PHI * m_mid(j-1) + m_mid(j);
            m_up(j) = PLOT_PHI * m_up(j-1) + m_up(j);
            m_down(j) = PLOT_PHI * m_down(j-1) + m_down(j);
         end;
      end;
   end;
   if DO_ONLY_MEDIAN,
      hndl = plot(ti,m_mid,'-',ti,0*ti,'-');
   else
      hndl = plot(ti,m_mid,'-',ti,m_up,'-',ti,m_down,'-',ti,0*ti);
   end;
   
   
   title('Monetary policy indicator');
   xlabel('Date'); % xlabel('month');
   ylabel('Indicator'); % ylabel('response');
   
   hpar = get(hndl(1),'Parent');
   set(hpar,'FontSize',FONT_SIZE);
   ht = get(hpar,'Title');
   set(ht,'FontSize',FONT_SIZE);
   hx = get(hpar,'XLabel');
   set(hx,'FontSize',FONT_SIZE);
   hy = get(hpar,'YLabel');
   set(hy,'FontSize',FONT_SIZE);
   if DO_EPSFILES,
      print -deps monindic.eps
   end;
end;
